@@ -1,7 +1,6 @@
 '''
     File: lineup.py
     Author: Drew Scott
-    Description: Implementation of a lineup using Players
 '''
 
 import pkg_resources
@@ -12,35 +11,45 @@ from .player import Player
 
 class Lineup:
     '''
-        Stores information about the current lineup
-        Contains methods to run simulations on the lineup
-    '''
+        Stores the players in a Lineup
 
-    data_directory = 'data/'
-    lineups_directory = 'teams/'
-    outcomes_directory = 'atbat_outcomes/'
-    stats_filename = 'stats.csv'
+        Public methods:
+            set_players: sets players in lineup either randomly or based on input filename
+            get_player: returns a Player instance who matches first_name and last_name from
+                the players list
+    '''
 
     def __init__(self):
         self.players: List[Player] = []
-        self.game_outcomes = []
+        self.random_lineup = True
 
-        # TODO: good place to put this?
-        Player.set_metadata(Lineup.stats_filename)
-
-    def add_player(self, player: Optional[Player]) -> None:
+    def set_players(self, lineup_filename: Optional[str] = None) -> None:
         '''
-            Adds a player to the lineup
+            Sets the players in this lineup
         '''
-        if player is None:
-            raise Exception('Tried adding None to lineup')
 
-        self.players.append(player)
+        # clear players
+        self.players = []
+
+        # add the players
+        if lineup_filename is None:
+            self._generate_random_lineup()
+            self.random_lineup = False
+        else:
+            self._generate_file_lineup(lineup_filename)
+            self.random_lineup = True
+
+        # display the players
+        print("Players:")
+        for player in self.players:
+            print(player)
+        print()
 
     def get_player(self, first_name: str, last_name: str) -> Player:
         '''
             Returns the player in the lineup who matches first and last name
         '''
+
         for player in self.players:
             if player.player_info['first_name'] == first_name \
                 and player.player_info['last_name'] == last_name:
@@ -48,24 +57,41 @@ class Lineup:
 
         raise Exception(f'Player {first_name} {last_name} not found from PA outcome file')
 
-    def set_players(self, lineup_filename: str) -> None:
+    def _generate_random_lineup(self) -> None:
+        '''
+            Generates a random lineup of 9 players drawn from stats_filename
+        '''
+
+        stats = pkg_resources.resource_stream(__name__, Player.stats_filepath).read().decode(encoding='utf-8-sig')
+        stat_lines = stats.split('\n')
+
+        # get all the players
+        players = []
+        for line in stat_lines[1:]:
+            players.append(Player(line))
+
+        # select 9 random players to add to the lineup
+        player_indexes = self._get_nine(len(players))
+        for index in player_indexes:
+            self._add_player(players[index])
+
+    def _generate_file_lineup(self, lineup_filename: str) -> None:
         '''
             Sets the players in the lineup file to this lineup, in the order listed in the file
         '''
 
-        lineup_filepath = Lineup.data_directory + Lineup.lineups_directory + lineup_filename
-        stats_filepath = Lineup.data_directory + Lineup.stats_filename
+        # TODO: what if lineup_filename not located in package contents (i.e. is user generated?)
+        lineup_filepath = Player.data_directory + Player.lineups_directory + lineup_filename
 
         # get the players specified in the input file
-        raw_players = pkg_resources.resource_stream(__name__, lineup_filepath).read().decode().split('\n')
+        raw_players = pkg_resources.resource_stream(__name__, lineup_filepath).read().decode().split('\n')[:-1]
         player_names = []
         for player in raw_players:
-            print(player)
             first, last = player.split()
             player_names.append(f'{last},{first}')
 
         # read the player data from the stats csv
-        stats = pkg_resources.resource_stream(__name__, stats_filepath).read().decode(encoding='utf-8-sig')
+        stats = pkg_resources.resource_stream(__name__, Player.stats_filepath).read().decode(encoding='utf-8-sig')
         stat_lines = stats.split('\n')
 
         players: List[Optional[Player]] = [None] * 9 
@@ -77,11 +103,21 @@ class Lineup:
                 players[player_names.index(name)] = Player(line)
 
         for player in players:
-            self.add_player(player)
+            self._add_player(player)
 
         if len(self.players) != 9:
             raise Exception(f'Incorrect number of players: {len(lineup.players)}, {lineup.players}')
 
+    def _add_player(self, player: Optional[Player]) -> None:
+        '''
+            Adds a player to the lineup
+        '''
+
+        if player is None:
+            raise Exception('Tried adding None to lineup')
+
+        self.players.append(player)
+
     @staticmethod
     def _get_nine(total_count: int) -> List[int]:
         '''
@@ -95,50 +131,3 @@ class Lineup:
                 nine.append(index)
 
         return nine
-
-    def generate_random_lineup(self) -> None:
-        '''
-            Generates a random lineup of 9 players drawn from stats_filename
-        '''
-
-        # TODO: maybe make this a static class variable?
-        stats_filepath = Lineup.data_directory + Lineup.stats_filename
-
-        stats = pkg_resources.resource_stream(__name__, stats_filepath).read().decode(encoding='utf-8-sig')
-        stat_lines = stats.split('\n')
-
-        # get all the players
-        players = []
-        for line in stat_lines[1:]:
-            players.append(Player(line))
-
-        # select 9 random players to add to the lineup
-        player_indexes = self._get_nine(len(players))
-        for index in player_indexes:
-            self.add_player(players[index])
-
-    def set_pa_outcomes(self, outcome_filename: Optional[str], sims_per_order: int) -> None:
-        '''
-            Generates the PA outcomes for each player for each game that will be simulated
-            Stores this information both in the Player instance and in this Lineup instance
-        '''
-
-        if outcome_filename is None:
-            for player in self.players:
-                player.generate_pa_outcomes(sims_per_order)
-
-        else:
-            outcome_filepath = Player.data_directory + Player.outcome_directory + outcome_filename
-            raw_outcomes = pkg_resources.resource_stream(__name__, outcome_filepath).read().decode().split('\n')
-            for player_outcome in raw_outcomes:
-                first_name, last_name = player_outcome.split(':')[0].split()
-                player = self.get_player(first_name, last_name)
-
-                player.set_pa_outcomes(player_outcome.split(':')[1][:-1].split(','))
-
-        for game_num in range(sims_per_order):
-            game_pas = {}
-            for i, player in enumerate(self.players):
-                game_pas[i] = player.pa_outcomes[game_num]
-
-            self.game_outcomes.append(game_pas)
